@@ -7,14 +7,8 @@ namespace LaminasTest\EventManager\TestAsset;
 use Laminas\EventManager\AbstractListenerAggregate;
 use Laminas\EventManager\EventManagerInterface;
 
-/**
- * @group      Laminas_EventManager
- */
 class MockAbstractListenerAggregate extends AbstractListenerAggregate
 {
-    /** @var null|int */
-    public $priority;
-
     /** @param int $priority */
     public function attach(EventManagerInterface $events, $priority = 1): void
     {
@@ -22,6 +16,7 @@ class MockAbstractListenerAggregate extends AbstractListenerAggregate
         $this->listeners[] = $events->attach('foo.baz', [$this, 'doFoo']);
     }
 
+    /** @return callable[] */
     public function getCallbacks(): array
     {
         return $this->listeners;
